# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: command_session/command_session.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'command_session/command_session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%command_session/command_session.proto\x12\x0f\x63ommand_session\"R\n\x03PTY\x12\'\n\x04size\x18\x01 \x01(\x0b\x32\x19.command_session.PTY.Size\x1a\"\n\x04Size\x12\x0c\n\x04\x63ols\x18\x01 \x01(\r\x12\x0c\n\x04rows\x18\x02 \x01(\r\"\xa5\x01\n\x0b\x43ommandSpec\x12\x0b\n\x03\x63md\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x34\n\x04\x65nvs\x18\x03 \x03(\x0b\x32&.command_session.CommandSpec.EnvsEntry\x12\x10\n\x03\x63wd\x18\x04 \x01(\tH\x00\x88\x01\x01\x1a+\n\tEnvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04_cwd\"\r\n\x0bListRequest\"j\n\x12\x43ommandSessionInfo\x12-\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x1c.command_session.CommandSpec\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x10\n\x03tag\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04_tag\"E\n\x0cListResponse\x12\x35\n\x08sessions\x18\x01 \x03(\x0b\x32#.command_session.CommandSessionInfo\"\xa5\x01\n\x0cStartRequest\x12-\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x1c.command_session.CommandSpec\x12&\n\x03pty\x18\x02 \x01(\x0b\x32\x14.command_session.PTYH\x00\x88\x01\x01\x12\x10\n\x03tag\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05stdin\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\x06\n\x04_ptyB\x06\n\x04_tagB\x08\n\x06_stdin\"y\n\rUpdateRequest\x12\x38\n\x07session\x18\x01 \x01(\x0b\x32\'.command_session.CommandSessionSelector\x12&\n\x03pty\x18\x02 \x01(\x0b\x32\x14.command_session.PTYH\x00\x88\x01\x01\x42\x06\n\x04_pty\"\x10\n\x0eUpdateResponse\"\xf2\x03\n\x13\x43ommandSessionEvent\x12@\n\x05start\x18\x01 \x01(\x0b\x32/.command_session.CommandSessionEvent.StartEventH\x00\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..command_session.CommandSessionEvent.DataEventH\x00\x12<\n\x03\x65nd\x18\x03 \x01(\x0b\x32-.command_session.CommandSessionEvent.EndEventH\x00\x12\x43\n\tkeepalive\x18\x04 \x01(\x0b\x32..command_session.CommandSessionEvent.KeepAliveH\x00\x1a\x19\n\nStartEvent\x12\x0b\n\x03pid\x18\x01 \x01(\r\x1aH\n\tDataEvent\x12\x10\n\x06stdout\x18\x01 \x01(\x0cH\x00\x12\x10\n\x06stderr\x18\x02 \x01(\x0cH\x00\x12\r\n\x03pty\x18\x03 \x01(\x0cH\x00\x42\x08\n\x06output\x1a[\n\x08\x45ndEvent\x12\x11\n\texit_code\x18\x01 \x01(\x11\x12\x0e\n\x06\x65xited\x18\x02 \x01(\x08\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x12\n\x05\x65rror\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\x1a\x0b\n\tKeepAliveB\x07\n\x05\x65vent\"D\n\rStartResponse\x12\x33\n\x05\x65vent\x18\x01 \x01(\x0b\x32$.command_session.CommandSessionEvent\"F\n\x0f\x43onnectResponse\x12\x33\n\x05\x65vent\x18\x01 \x01(\x0b\x32$.command_session.CommandSessionEvent\"z\n\x10SendInputRequest\x12\x38\n\x07session\x18\x01 \x01(\x0b\x32\'.command_session.CommandSessionSelector\x12,\n\x05input\x18\x02 \x01(\x0b\x32\x1d.command_session.CommandInput\"\x13\n\x11SendInputResponse\"7\n\x0c\x43ommandInput\x12\x0f\n\x05stdin\x18\x01 \x01(\x0cH\x00\x12\r\n\x03pty\x18\x02 \x01(\x0cH\x00\x42\x07\n\x05input\"\xf1\x02\n\x12StreamInputRequest\x12?\n\x05start\x18\x01 \x01(\x0b\x32..command_session.StreamInputRequest.StartEventH\x00\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.command_session.StreamInputRequest.DataEventH\x00\x12\x42\n\tkeepalive\x18\x03 \x01(\x0b\x32-.command_session.StreamInputRequest.KeepAliveH\x00\x1a\x46\n\nStartEvent\x12\x38\n\x07session\x18\x01 \x01(\x0b\x32\'.command_session.CommandSessionSelector\x1a\x39\n\tDataEvent\x12,\n\x05input\x18\x02 \x01(\x0b\x32\x1d.command_session.CommandInput\x1a\x0b\n\tKeepAliveB\x07\n\x05\x65vent\"\x15\n\x13StreamInputResponse\"v\n\x11SendSignalRequest\x12\x38\n\x07session\x18\x01 \x01(\x0b\x32\'.command_session.CommandSessionSelector\x12\'\n\x06signal\x18\x02 \x01(\x0e\x32\x17.command_session.Signal\"\x14\n\x12SendSignalResponse\"J\n\x0e\x43onnectRequest\x12\x38\n\x07session\x18\x01 \x01(\x0b\x32\'.command_session.CommandSessionSelector\"B\n\x16\x43ommandSessionSelector\x12\r\n\x03pid\x18\x01 \x01(\rH\x00\x12\r\n\x03tag\x18\x02 \x01(\tH\x00\x42\n\n\x08selector*H\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12\x12\n\x0eSIGNAL_SIGTERM\x10\x0f\x12\x12\n\x0eSIGNAL_SIGKILL\x10\t2\xc1\x04\n\x0e\x43ommandSession\x12\x43\n\x04List\x12\x1c.command_session.ListRequest\x1a\x1d.command_session.ListResponse\x12N\n\x07\x43onnect\x12\x1f.command_session.ConnectRequest\x1a .command_session.ConnectResponse0\x01\x12H\n\x05Start\x12\x1d.command_session.StartRequest\x1a\x1e.command_session.StartResponse0\x01\x12I\n\x06Update\x12\x1e.command_session.UpdateRequest\x1a\x1f.command_session.UpdateResponse\x12Z\n\x0bStreamInput\x12#.command_session.StreamInputRequest\x1a$.command_session.StreamInputResponse(\x01\x12R\n\tSendInput\x12!.command_session.SendInputRequest\x1a\".command_session.SendInputResponse\x12U\n\nSendSignal\x12\".command_session.SendSignalRequest\x1a#.command_session.SendSignalResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'command_session.command_session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMMANDSPEC_ENVSENTRY']._loaded_options = None
  _globals['_COMMANDSPEC_ENVSENTRY']._serialized_options = b'8\001'
  _globals['_SIGNAL']._serialized_start=2339
  _globals['_SIGNAL']._serialized_end=2411
  _globals['_PTY']._serialized_start=58
  _globals['_PTY']._serialized_end=140
  _globals['_PTY_SIZE']._serialized_start=106
  _globals['_PTY_SIZE']._serialized_end=140
  _globals['_COMMANDSPEC']._serialized_start=143
  _globals['_COMMANDSPEC']._serialized_end=308
  _globals['_COMMANDSPEC_ENVSENTRY']._serialized_start=257
  _globals['_COMMANDSPEC_ENVSENTRY']._serialized_end=300
  _globals['_LISTREQUEST']._serialized_start=310
  _globals['_LISTREQUEST']._serialized_end=323
  _globals['_COMMANDSESSIONINFO']._serialized_start=325
  _globals['_COMMANDSESSIONINFO']._serialized_end=431
  _globals['_LISTRESPONSE']._serialized_start=433
  _globals['_LISTRESPONSE']._serialized_end=502
  _globals['_STARTREQUEST']._serialized_start=505
  _globals['_STARTREQUEST']._serialized_end=670
  _globals['_UPDATEREQUEST']._serialized_start=672
  _globals['_UPDATEREQUEST']._serialized_end=793
  _globals['_UPDATERESPONSE']._serialized_start=795
  _globals['_UPDATERESPONSE']._serialized_end=811
  _globals['_COMMANDSESSIONEVENT']._serialized_start=814
  _globals['_COMMANDSESSIONEVENT']._serialized_end=1312
  _globals['_COMMANDSESSIONEVENT_STARTEVENT']._serialized_start=1098
  _globals['_COMMANDSESSIONEVENT_STARTEVENT']._serialized_end=1123
  _globals['_COMMANDSESSIONEVENT_DATAEVENT']._serialized_start=1125
  _globals['_COMMANDSESSIONEVENT_DATAEVENT']._serialized_end=1197
  _globals['_COMMANDSESSIONEVENT_ENDEVENT']._serialized_start=1199
  _globals['_COMMANDSESSIONEVENT_ENDEVENT']._serialized_end=1290
  _globals['_COMMANDSESSIONEVENT_KEEPALIVE']._serialized_start=1292
  _globals['_COMMANDSESSIONEVENT_KEEPALIVE']._serialized_end=1303
  _globals['_STARTRESPONSE']._serialized_start=1314
  _globals['_STARTRESPONSE']._serialized_end=1382
  _globals['_CONNECTRESPONSE']._serialized_start=1384
  _globals['_CONNECTRESPONSE']._serialized_end=1454
  _globals['_SENDINPUTREQUEST']._serialized_start=1456
  _globals['_SENDINPUTREQUEST']._serialized_end=1578
  _globals['_SENDINPUTRESPONSE']._serialized_start=1580
  _globals['_SENDINPUTRESPONSE']._serialized_end=1599
  _globals['_COMMANDINPUT']._serialized_start=1601
  _globals['_COMMANDINPUT']._serialized_end=1656
  _globals['_STREAMINPUTREQUEST']._serialized_start=1659
  _globals['_STREAMINPUTREQUEST']._serialized_end=2028
  _globals['_STREAMINPUTREQUEST_STARTEVENT']._serialized_start=1877
  _globals['_STREAMINPUTREQUEST_STARTEVENT']._serialized_end=1947
  _globals['_STREAMINPUTREQUEST_DATAEVENT']._serialized_start=1949
  _globals['_STREAMINPUTREQUEST_DATAEVENT']._serialized_end=2006
  _globals['_STREAMINPUTREQUEST_KEEPALIVE']._serialized_start=1292
  _globals['_STREAMINPUTREQUEST_KEEPALIVE']._serialized_end=1303
  _globals['_STREAMINPUTRESPONSE']._serialized_start=2030
  _globals['_STREAMINPUTRESPONSE']._serialized_end=2051
  _globals['_SENDSIGNALREQUEST']._serialized_start=2053
  _globals['_SENDSIGNALREQUEST']._serialized_end=2171
  _globals['_SENDSIGNALRESPONSE']._serialized_start=2173
  _globals['_SENDSIGNALRESPONSE']._serialized_end=2193
  _globals['_CONNECTREQUEST']._serialized_start=2195
  _globals['_CONNECTREQUEST']._serialized_end=2269
  _globals['_COMMANDSESSIONSELECTOR']._serialized_start=2271
  _globals['_COMMANDSESSIONSELECTOR']._serialized_end=2337
  _globals['_COMMANDSESSION']._serialized_start=2414
  _globals['_COMMANDSESSION']._serialized_end=2991
# @@protoc_insertion_point(module_scope)
